clustering: Method to extract the clustering results from an IclFit-class object
Description
This method take a IclFit-class object and return an integer vector with the cluster assignments that were found.
Usage
clustering(fit)# S4 method for IclFit
clustering(fit)
Value
an integer vector with cluster assignments. Zero indicates noise points.
Arguments
- fit
an IclFit solution