An S4 class to represent a Multinomial Stochastic Block Model, extends icl_model-class. Such model can be used to cluster multilayer-graph vertex, and model a square adjacency cube \(X\) of size NxNxM with the following generative model :
$$ \pi \sim Dirichlet(\alpha)$$
$$ Z_i \sim \mathcal{M}(1,\pi)$$
$$ \theta_{kl} \sim Dirichlet(\beta)$$
$$ X_{ij.}|Z_{ik}Z_{jl}=1 \sim \mathcal{M}(L_{ij},\theta_{kl})$$
With \(L_{ij}=\sum_{m=1}^MX_{ijm}\). This class mainly store the prior parameters value \(\alpha,\beta\) of this generative model in the following slots:
namename of the model
alphaDirichlet over cluster proportions prior parameter
betaDirichlet prior parameter over Multinomial links
typedefine the type of networks (either "directed" or "undirected", default to "directed")